@@ -1,19 +1,23 @@
-# Copyright (c) 2016, 2017, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from __future__ import with_statement
 
@@ -28,6 +32,8 @@ from workbench.utils import Version
 
 from workbench.log import log_debug3, log_debug2, log_error, log_warning
 
+from wb_common import to_unicode
+
 last_location = ""
 
 def showPowerImport(editor, selection):
@@ -51,10 +57,10 @@ def handleContextMenu(name, sender, args):
     
     for s in selection:
         if s.type == 'db.Schema':
-            user_selection = {'schema': s.name, 'table': None}
+            user_selection = {'schema': to_unicode(s.name), 'table': None}
             break
         elif s.type == 'db.Table':
-            user_selection = {'table': s.name, 'schema': s.schemaName}
+            user_selection = {'table': to_unicode(s.name), 'schema': to_unicode(s.schemaName)}
             break
         else:
             return
@@ -234,7 +240,7 @@ class base_module:
     def prepare_new_table(self):
         try:
             
-            self._editor.executeManagementCommand(""" CREATE TABLE %s (%s)""" % (self._table_w_prefix, ", ".join(["`%s` %s" % (col['name'], col["type"]) for col in self._mapping])), 1)
+            self._editor.executeManagementCommand(""" CREATE TABLE %s (%s)""" % (self._table_w_prefix, ", ".join(["`%s` %s" % (col['name'], col["type"]) for col in self._mapping if col['active'] is True])), 1)
             self.update_progress(0.0, "Prepared new table")
             # wee need to setup dest_col for each row, as the mapping is empty if we're creating new table
             for col in self._mapping:
@@ -312,7 +318,7 @@ class csv_module(base_module):
         base_module.__init__(self, editor, is_import)
         self.name = "csv"
         self.title = self.name
-        self.options = {'filedseparator': {'description':'Field Separator', 'type':'select', 'opts':{'TAB':'\t',';':';', ':':':', ',':','}, 'value':';', 'entry': None},
+        self.options = {'filedseparator': {'description':'Field Separator', 'type':'select', 'opts':{'TAB':'\t','|':'|',';':';', ':':':', ',':','}, 'value':';', 'entry': None},
                 'lineseparator': {'description':'Line Separator', 'type':'select','opts':{"CR":'\r', "CR LF":'\r\n', "LF":'\n'}, 'value':'\n', 'entry': None}, 
                 'encolsestring': {'description':'Enclose Strings in', 'type':'text', 'value':'"', 'entry': None}};
         
@@ -590,7 +596,7 @@ class json_module(base_module):
             limit = "LIMIT %d" % int(self._limit)
             if self._offset:
                 limit = "LIMIT %d,%d" % (int(self._offset), int(self._limit))
-        return """SELECT %s FROM %s %s""" % (",".join(["`%s`" % value['name'] for value in self._columns]), self._table_w_prefix, limit)                
+        return u"""SELECT %s FROM %s %s""" % (",".join(["`%s`" % value['name'] for value in self._columns]), self._table_w_prefix, limit)                
     
     def start_export(self):
         if self._user_query:
@@ -635,11 +641,12 @@ class json_module(base_module):
                             row.append("\"%s\":%s" % (col['name'], rset.geoJsonFieldValueByName(col['name'])))
                         else:
                             if col['type'] == "json":
-                                row.append("\"%s\":%s" % (col['name'], rset.stringFieldValueByName(col['name'])))
+                                row.append(u"\"%s\":%s" % (col['name'], to_unicode(rset.stringFieldValueByName(col['name']))))
                             else:
-                                row.append("\"%s\":%s" % (col['name'], json.dumps(rset.stringFieldValueByName(col['name']))))
+                                row.append("\"%s\":%s" % (col['name'], json.dumps(to_unicode(rset.stringFieldValueByName(col['name'])))))
                     ok = rset.nextRow()
-                    jsonfile.write("{%s}%s" % (', '.join(row), ",\n " if ok else ""))
+                    line = u"{%s}%s" % (', '.join(row), ",\n " if ok else "")
+                    jsonfile.write(line.encode('utf-8'))
                     jsonfile.flush()
                 jsonfile.write(']')
 
@@ -763,6 +770,10 @@ class json_module(base_module):
             return False
         
         self._columns = []
+        
+        if type(data) == dict: # We need to have list so if it's dict after that we will be able to handle it.
+            data = [data]
+        
         for elem in data[0]:
             self._columns.append({'name': elem, 'type': 'text', 'is_string': True, 'is_geometry': False, 'is_bignumber': False, 'is_number': False, 'is_date_or_time': False, 'is_bin': False, 'is_float':False, 'is_json':False, 'value': []})
 
