@@ -1,19 +1,23 @@
-# Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2018, Oracle and/or its affiliates. All rights reserved.
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License as
-# published by the Free Software Foundation; version 2 of the
-# License.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License, version 2.0,
+# as published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms, as
+# designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an additional
+# permission to link the program and your derivative works with the
+# separately licensed software that they have included with MySQL.
+# This program is distributed in the hope that it will be useful,  but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
+# the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301  USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
 from workbench.log import log_error
 from workbench.db_utils import QueryError
@@ -70,7 +74,7 @@ class PSInstrumentGroup(ChangeNotifierDict):
 
     def update_parents_state(self, attr):
         """
-        Updates the paren's states based on the children
+        Updates the parent's states based on the children
         status on a line of the hierarchy tree.
         """
         parent = self.parent
@@ -83,7 +87,7 @@ class PSInstrumentGroup(ChangeNotifierDict):
         """
         Updates the status of an attribute in an element 
         of the hierarchy tree, including all the branch
-        below it and it's parents
+        below it and its parents
         """
         if attr == 'enabled':
             self.enabled = value
@@ -97,7 +101,7 @@ class PSInstrumentGroup(ChangeNotifierDict):
     def set_state_from_children(self, attr):
         """
         Sets the status of an element of the hierarchy based
-        on the status of it's immediate childrens
+        on the status of its immediate childrens
         """
         counter = 0
         for child in self.keys():
@@ -155,7 +159,7 @@ class PSInstrumentGroup(ChangeNotifierDict):
 
 class PSInstruments(ChangeCounter):
     """
-    Database manager for PS Instruments it's functions are loading/committing changes
+    Database manager for PS Instruments its functions are loading/committing changes
     to the database.
     """
     def __init__(self, ctrl_be):
@@ -392,7 +396,7 @@ class PSVariables(dict, ChangeCounter):
 
     def load(self):
         try:
-            result = self.ctrl_be.exec_query('SHOW variables LIKE "performance_schema%"')
+            result = self.ctrl_be.exec_query("SHOW variables LIKE 'performance_schema%'")
 
             if result is not None:
                 while result.nextRow():
@@ -615,7 +619,6 @@ class PSThread(ChangeTracker):
         self.plist_state = ""
         self.plist_info = ""
         self.parent_id = ""
-        self.role = ""
 
 
 class PSThreads(ChangeNotifierDict):
@@ -629,7 +632,7 @@ class PSThreads(ChangeNotifierDict):
             result = self.ctrl_be.exec_query('SELECT THREAD_ID, NAME, TYPE, PROCESSLIST_ID, PROCESSLIST_USER,'
                                              'PROCESSLIST_HOST, PROCESSLIST_DB, PROCESSLIST_COMMAND, PROCESSLIST_TIME,'
                                              'PROCESSLIST_STATE, SUBSTRING(PROCESSLIST_INFO, 1, 80) AS INFO,'
-                                             'PARENT_THREAD_ID,ROLE, INSTRUMENTED FROM performance_schema.threads')
+                                             'PARENT_THREAD_ID, INSTRUMENTED FROM performance_schema.threads')
 
             if result is not None:
                 while result.nextRow():
@@ -650,7 +653,6 @@ class PSThreads(ChangeNotifierDict):
                     thread.plist_state = result.stringByName('PROCESSLIST_STATE') or ""
                     thread.plist_info = result.stringByName('INFO') or ""
                     thread.parent_id = result.stringByName('PARENT_THREAD_ID') or ""
-                    thread.role = result.stringByName('ROLE') or ""
 
                     # At this point the threads is considered loaded
                     # so resets the change tracking system
